/*********************************************************************
 * 
 *    Filename:  output.h
 *    Author:    Ryan Shillington <shillington@writeme.com>
 *  
 *     This program is free software; you can redistribute it and/or
 *     modify it under the terms of the GNU General Public License as
 *     published by the Free Software Foundation; either version 2 of
 *     the License, or (at your option) any later version.
 *
 ********************************************************************/

#ifndef OUTPUT_H
#define OUTPUT_H

//* This defines a single Button (ie. Play on a Remote or an 'Enter' Key)
typedef struct {
  int key;
  char *keyChar;
  char code[64];
  unsigned int codeLen;
} Key;

/*********************************************************************
* 
*   Function Index
*
*  parseKeys - Parse a configuration file so that we can understand
*              the codes that are comming from the InfrRed Port.
*
*  convertKey - Converts a string in the right keystroke (ie. 'a' -> 97)
*
*  diff - intelligently tells you how many differences (in bytes) there
*         are between the 2 inputs, making sure not to go over maxdiff
*
*  handleSpecialChar - Handles the printing of special characters (or
*         characters that don't have any ascii (ie. PLAY, STOP))
*
*********************************************************************/
int convertKey(char *temp);
void parseKeys();
int diff(char *str1, int len1,  char *str2, int len2, int maxdiff);
void handleSpecialChar(int i);

// Setup the debug ability
#ifndef NET_DEBUG
#define NET_DEBUG 4
#define DEBUG(n, args...) if (NET_DEBUG >= (n)) printf(args)
#endif /* NET_DEBUG */

//* The Key code definitions for different non-alphanumeric keys
#define CAPS -2

#endif // OUTPUT_H
